<!--
|*master*|*develop*|
|:-:|:-:|
|[![Build Status](https://git.biohpc.swmed.edu/BICF/gudmap_rbk/rna-seq/badges/master/build.svg)](https://git.biohpc.swmed.edu/BICF/gudmap_rbk/rna-seq/commits/master)|[![Build Status](https://git.biohpc.swmed.edu/BICF/gudmap_rbk/rna-seq/badges/develop/build.svg)](https://git.biohpc.swmed.edu/BICF/gudmap_rbk/rna-seq/commits/develop)|

[![DOI]()]()
-->
GUDMAP/RBK scRNA-Seq Image Generation Pipeline
===========================

Introduction
------------


To Run:
-------
* **Available parameters:**
    * *--rda* R datafile
    * *--seurat* name of Seurat object in R datafile
    * *--tsne* true/false if tSNE calculated in Seurat object
    * *--umap* true/false if UMAP calculated in Seurat object
    * *--assay* name of assay in Seurat object to use for expression
    * *--slot* name of slot in Seurat object to use for expression
    * *--scale* true/false if assay needs scaling in Seurat object for expression
    * *--sample* number of cells to downsample Seurat object (0 for no downsampling)
    * *--groups* .csv file with a list of identity groups (1 pdf line) to output images for in Seurat object
    * *--convert* reference used in Seurat object for conversion to NCBI ID ("NO" for no conversion), must have a conversion file named *.to.NCBI.txt in .workflow/files to work
    * *--outDir* optional output directiory location
* **FULL EXAMPLE:**
  ```
  nextflow run workflow/scrna-seg_imgen.nf --rda ./data/sc10x.R --seurat sc10x --tsne true --umap false --assay RNA --slot scale.data --scale true --sample 0 --groups ./data/groups.csv --convert GRCh38p5
  ```
* **Processes**
    * *createMatrix*
        * Inputs:
            * R datafile
            * Seurat object name
            * Calculate tSNE?
            * Calculate UMAP?
            * Seurat assay
            * Seurat slot
            * Scale?
            * Number of cells to sample to
        * Outputs:
            * Raw matrix file (similar to 10x Genomics output)
    * *createGroups*
        * Inputs:
            * R datafile
            * Seurat object name
            * Groups to use
            * Downsampled cell barcodes
        * Outputs:
            * Files with cell barcodes and identities
    * *renameGenes*
        * Inputs:
            * Raw matrix files
            * Reference genome to convert
            * NCBI ID conversion file
        * Outputs:
            * Final matrix files
    * *plotIdentGroup*
        * Inputs:
            * Final matrix files
            * Identity groups
            * Calculate tSNE?
            * Calculate UMAP?
        * Outputs:
            * Image Group plots
    * *plotFeatures*
        * Inputs:
            * Final matrix
            * Chunked genes (1000 genes per chunk)
            * Calculate tSNE?
            * Calculate UMAP?
        * Outputs:
            * Feature plots
    * *plotViolinBox*
        * Inputs:
            * Final matrix
            * Chunked genes (1000 genes per chunk)
            * Identity groups
            * Identity group lists
        * Output:
            * Violin Box plot

[**CHANGELOG**](https://git.biohpc.swmed.edu/BICF/gudmap_rbk/scrna-seq_imgen/blob/develop/CHANGELOG.md)

---

Credits
=======
This worklow is was developed by [Bioinformatic Core Facility (BICF), Department of Bioinformatics](http://www.utsouthwestern.edu/labs/bioinformatics/)

PI
--
Venkat S. Malladi\
*Faculty Associate & Director*\
Bioinformatics Core Facility\
UT Southwestern Medical Center\
<a href="https://orcid.org/0000-0002-0144-0564" target="orcid.widget" rel="noopener noreferrer" style="vertical-align:top;"><img src="https://orcid.org/sites/default/files/images/orcid_16x16.png" style="width:1em;margin-right:.5em;" alt="ORCID iD icon">orcid.org/0000-0002-0144-0564</a>\
[venkat.malladi@utsouthwestern.edu](mailto:venkat.malladi@utsouthwestern.edu)

**AND**

Douglas W. Strand\
*Assistant Professor*\
Department of Urology\
UT Southwestern Medical Center\
<a href="https://orcid.org/0000-0002-0746-927X" target="orcid.widget" rel="noopener noreferrer" style="vertical-align:top;"><img src="https://orcid.org/sites/default/files/images/orcid_16x16.png" style="width:1em;margin-right:.5em;" alt="ORCID iD icon">orcid.org/0000-0002-0746-927X</a>\
[douglas.strand@utsouthwestern.edu](mailto:douglas.strand@utsouthwestern.edu)


Developers
----------
Gervaise H. Henry\
*Computational Biologist*\
Department of Urology\
UT Southwestern Medical Center\
<a href="https://orcid.org/0000-0001-7772-9578" target="orcid.widget" rel="noopener noreferrer" style="vertical-align:top;"><img src="https://orcid.org/sites/default/files/images/orcid_16x16.png" style="width:1em;margin-right:.5em;" alt="ORCID iD icon">orcid.org/0000-0001-7772-9578</a>\
[gervaise.henry@utsouthwestern.edu](mailto:gervaise.henry@utsouthwestern.edu)