if ("optparse" %in% row.names(installed.packages()) == FALSE){
  install.packages("optparse",repos="http://cran.us.r-project.org")
}
library(optparse)
library(Seurat)
library(readr)
library(Matrix)

#Get param inputs
option_list=list(
  make_option("--r",action="store",type='character',help="R data filename"),
  make_option("--o",action="store",type='character',help="Seurat object name"),
  make_option("--t",action="store",type='logical',default=TRUE,help="tSNE calculated?"),
  make_option("--u",action="store",type='logical',default=FALSE,help="UMAP calculated?"),
  make_option("--a",action="store",type='character',default="RNA",help="Seurat assay to use"),
  make_option("--s",action="store",type='character',default="scale.data",help="Seurat slot to use"),
  make_option("--l",action="store",type='logical',default=FALSE,help="Perform scaling?"),
  make_option("--p",action="store",type='integer',default=0,help="Sample quantity")
)
opt=parse_args(OptionParser(option_list=option_list))
rm(option_list)

#Create output folders
if (!dir.exists("./matrix")){
  dir.create("./matrix")
}
if (!dir.exists("./matrix/raw")){
  dir.create("./matrix/raw")
}

#Load Seurat R data file and update
load(opt$r)
data <- get(opt$o)
rm(list=opt$o)
try(
  if (as.numeric(substring(data@version,1,1))<3){
    data <- UpdateSeuratObject(data)
  }
)
if (opt$l == TRUE){
  data <- ScaleData(data,assay=opt$a,features=rownames(data))
}

#Downsample cells
if (opt$p != 0){
  Idents(data) <- "ALL"
  data <- subset(data,cells=WhichCells(data,downsample=opt$p,seed=1))
}

#Write cell/gene matrix files
writeMM(Matrix(GetAssayData(data,assay=opt$a,slot=opt$s),sparse=TRUE),file="./matrix/raw/expression.mtx")
write.table(rownames(data),file=paste0("./matrix/raw/genes.csv"),row.names=FALSE,col.names=FALSE,append=FALSE,sep=",")
write.table(colnames(data),file=paste0("./matrix/raw/cells.csv"),row.names=FALSE,col.names=FALSE,append=FALSE,sep=",")
write.table(colnames(data),file=paste0("./cells.csv"),row.names=FALSE,col.names=FALSE,append=FALSE,sep=",")

#Write dimentionality reduction
if (opt$t){
  write.table(Embeddings(data,reduction="tsne"),file=paste0("./matrix/raw/dr_tSNE.csv"),row.names=TRUE,col.names=NA,append=FALSE,sep=",")
}
if (opt$u){
  write.table(Embeddings(data,reduction="umap"),file=paste0("./matrix/raw/dr_UMAP.csv"),row.names=TRUE,col.names=NA,append=FALSE,sep=",")
}