if ("optparse" %in% row.names(installed.packages()) == FALSE){
  install.packages("optparse",repos="http://cran.us.r-project.org")
}
library(optparse)
library(Matrix)
library(readr)
library(ggplot2)
library(cowplot)

#Get param inputs
option_list=list(
  make_option("--t",action="store",type='logical',default=TRUE,help="tSNE calculated?"),
  make_option("--u",action="store",type='logical',default=FALSE,help="UMAP calculated?"),
  make_option("--c",action="store",type='character',help="Gene chunk filename")
)
opt=parse_args(OptionParser(option_list=option_list))
rm(option_list)

#Load data
exp <- readMM("./expression.mtx")
exp <- as.data.frame(as.matrix(exp))
genes <- read.table("./genes.csv",quote="\"")
exp$genes <- genes$V1

#Load gene chunk
chunk <- read.csv(opt$c,header=FALSE)

#Filter expression data
exp <- exp[exp$genes %in% chunk$V1,]

#Load dr
if (opt$t == TRUE){
  dr.tsne <- read.csv(paste0("./dr_tSNE.csv"),header=TRUE)
  colnames(dr.tsne)[1] <- "Cells"
  if (!dir.exists("./tsne")){
    dir.create("./tsne")
  }
}
if (opt$u == TRUE){
  dr.umap <- read.csv(paste0("./dr_UMAP.csv"),header=TRUE)
  colnames(dr.umap)[1] <- "Cells"
  if (!dir.exists("./umap")){
    dir.create("./umap")
  }
}

#Plot
for (i in chunk$V1){
  hi <- max(as.numeric(exp[which(exp$genes==i),])[-ncol(exp)])
  lo <- min(as.numeric(exp[which(exp$genes==i),])[-ncol(exp)])
  
  if (opt$t == TRUE){
    dr <- dr.tsne
    dr$Expression <- as.numeric(exp[which(exp$genes==i),])[-ncol(exp)]
    png(paste0("./tsne/",i,".png"),width=400,height=400,bg="white")
    plot(ggplot(dr,aes(x=tSNE_1,y=tSNE_2,col=Expression))+geom_point(size=2)+scale_colour_gradient(low="grey",high="darkred",limits=c(lo,hi))+theme_cowplot())
    dev.off()
    rm(dr)
  }
  if (opt$u == TRUE){
    dr <- dr.umap
    dr$Expression <- as.numeric(exp[which(exp$genes==i),])[-ncol(exp)]
    png(paste0("./umap/",i,".png"),width=500,height=500,bg="white")
    plot(ggplot(dr,aes(x=UMAP_1,y=UMAP_2,col=Expression))+geom_point(size=2)+scale_colour_gradient(low="grey",high="darkred",limits=c(lo,hi))+theme_cowplot())
    dev.off()
    rm(dr)
  }
  rm(hi)
  rm(lo)
}