if ("optparse" %in% row.names(installed.packages()) == FALSE){
  install.packages("optparse",repos="http://cran.us.r-project.org")
}
library(optparse)
library(Matrix)
library(readr)
library(ggplot2)
library(cowplot)

#Get param inputs
option_list=list(
  make_option("--g",action="store",type='character',help="Seurat group ident"),
  make_option("--c",action="store",type='character',help="Gene chunk filename")
)
opt=parse_args(OptionParser(option_list=option_list))
rm(option_list)

#Load group
id <- read.csv(paste0("./group_",opt$g,".csv"),header=FALSE)
names(id)[2] <- opt$g

#Load data
exp <- readMM("./expression.mtx")
exp <- as.data.frame(as.matrix(exp))
genes <- read.table("./genes.csv",quote="\"")
exp$genes <- genes$V1

#Load gene chunk
chunk <- read.csv(opt$c,header=FALSE)

#Filter expression data
exp <- exp[exp$genes %in% chunk$V1,]

#Create output folders
if (!dir.exists(paste0("./",opt$g))){
  dir.create(paste0("./",opt$g))
}

#Plot
for (i in chunk$V1){
  id.exp <- id
  id.exp$Expression <- as.numeric(exp[which(exp$genes==i),])[-ncol(exp)]
  png(paste0("./",opt$g,"/",i,".png"),width=1000,height=500,bg="white")
  plot(ggplot(id.exp,aes_string(x=opt$g,y="Expression",fill=opt$g))+geom_violin(scale="width",trim=TRUE)+labs(y="Expression")+geom_boxplot(width=0.25,fill="white",outlier.shape=NA)+theme_cowplot())
  dev.off()
  rm(id.exp)
}
