if ("optparse" %in% row.names(installed.packages()) == FALSE){
  install.packages("optparse",repos="http://cran.us.r-project.org")
}
library(optparse)
library(readr)
library(Matrix)

#Get param inputs
option_list=list(
  make_option("--g",action="store",type='character',help="NCBI conversion filename")
)
opt=parse_args(OptionParser(option_list=option_list))
rm(option_list)

#Load genes and conversion files
genes <- read.table("./raw/genes.csv",quote="\"")
convert <- read.delim(paste0("../../../workflow/files/",opt$g,".to.NCBI.txt"))

#Filter gene to good conversions
genes.noambig <- merge(x=genes,y=convert[,2:3],by.x="V1",by.y="Associated.Gene.Name",all=TRUE)
genes.noambig <- genes.noambig[!(duplicated(genes.noambig$V1)|duplicated(genes.noambig$V1,fromLast=TRUE)),]
genes.noambig <- genes.noambig[!(duplicated(genes.noambig$EntrezGene.ID)|duplicated(genes.noambig$EntrezGene.ID,fromLast=TRUE)),]
genes.noambig <- as.data.frame(genes.noambig)
genes.noambig$V1 <- as.character(genes.noambig$V1)
genes.noambig$EntrezGene.ID <- as.numeric(genes.noambig$EntrezGene.ID)
genes.noambig.filtered <- genes.noambig[genes.noambig$V1 %in% genes$V1,]
colnames(genes.noambig.filtered) <- c("GeneName","EntrezGene.ID")

#Load matrix
exp <- readMM("./raw/expression.mtx")
exp <- as.data.frame(as.matrix(exp))
exp$gene <- genes$V1

#Filter matrix
exp.new <- merge(y=genes.noambig.filtered,x=exp,by.y="GeneName",by.x="gene",all.y=TRUE)
exp.new <- as.data.frame(exp.new)
exp.new <- exp.new[,-1]

#Write matrix and gene list
write.table(as.character(exp.new$EntrezGene.ID),file="./genes.csv",append=FALSE,quote=TRUE,sep=",",row.names=FALSE,col.names=FALSE)
exp.new.mm <- as(as.matrix(exp.new[,-ncol(exp.new)]),"dgTMatrix")
writeMM(exp.new.mm,file="./expression.mtx")